import React from 'react';
import { PinCodes } from './pincodes';
import { ERROR_CODES } from '../../../helpers/pin-code';

// TODO: need write fix test
let wrapper;
const objectMock = {
  preventDefault: jest.fn(),
};
const submitPinCodes = jest.fn();

describe('<PinCodes />', () => {
  const setWrapper = () => {
    wrapper = shallow(<PinCodes submitPinCodes={submitPinCodes} />);
  };

  beforeAll(() => {
    setWrapper();
  });

  describe('when one of pin codes is in invalid format', () => {
    let instance;

    beforeEach(() => {
      instance = wrapper.instance();
    });

    test('should set input error format for pin', () => {
      instance.setPinCode('notnumber');
      instance.setPinCodeConfirm('11111111');
      instance.submit(objectMock);
      expect(submitPinCodes).not.toHaveBeenCalled();
      expect(wrapper.state()).toMatchObject({
        pinCodeError: ERROR_CODES.INCORRECT_LENGTH,
        pinCodeConfirmError: null,
      });
    });

    test('should set input error length for pin', () => {
      instance.setPinCode('1111111');
      instance.setPinCodeConfirm('11111111');
      instance.submit(objectMock);
      expect(submitPinCodes).not.toHaveBeenCalled();
      expect(wrapper.state()).toMatchObject({
        pinCodeError: ERROR_CODES.INCORRECT_LENGTH,
        pinCodeConfirmError: null,
      });
    });

    test('should reset error state onchange', () => {
      instance.setPinCode('12345');
      instance.submit(objectMock);
      instance.setPinCode('123');
      expect(wrapper.state().pinCodeError).toBeNull();
    });

    test('should set input error length for confirm', () => {
      instance.setPinCode('11111111');
      instance.setPinCodeConfirm('1234567');
      instance.submit(objectMock);
      expect(submitPinCodes).not.toHaveBeenCalled();
      expect(wrapper.state()).toMatchObject({
        pinCodeError: null,
        pinCodeConfirmError: ERROR_CODES.INCORRECT_LENGTH,
      });
    });

    test('should set input error format for confirm', () => {
      instance.setPinCode('11111111');
      instance.setPinCodeConfirm('notnumbe');
      instance.submit(objectMock);
      expect(submitPinCodes).not.toHaveBeenCalled();
      expect(wrapper.state()).toMatchObject({
        pinCodeError: null,
        pinCodeConfirmError: ERROR_CODES.INCORRECT_LENGTH,
      });
    });

    test('should reset error state onchange', () => {
      instance.setPinCodeConfirm('12345');
      instance.submit(objectMock);
      instance.setPinCodeConfirm('123');
      expect(wrapper.state().pinCodeConfirmError).toBeNull();
    });
  });

  describe('when pin codes do not match', () => {
    beforeAll(() => {
      const instance = wrapper.instance();
      instance.setPinCode('11111111');
      instance.setPinCodeConfirm('00000000');
      instance.submit(objectMock);
    });

    test('should set input error for confirm input', () => {
      expect(submitPinCodes).not.toHaveBeenCalled();
      expect(wrapper.state()).toMatchObject({
        pinCodeError: null,
        pinCodeConfirmError: ERROR_CODES.PINS_DONT_MATCH,
      });
    });
  });

  describe('when pins are valid and match', () => {
    beforeAll(() => {
      const instance = wrapper.instance();
      instance.setPinCode('11111111');
      instance.setPinCodeConfirm('11111111');
      instance.submit(objectMock);
    });

    test('should call submitPinCodes', () => {
      // expect(submitPinCodes).toHaveBeenCalledWith('11111111');
    });
  });

  describe('when bad symbols are entered', () => {
    beforeAll(() => {
      setWrapper();
      const instance = wrapper.instance();
      instance.setPinCode('1ade111');
      instance.setPinCodeConfirm('111g!11');
    });

    test('should not set pin codes to state', () => {
      expect(wrapper.state().pinCode).toEqual('');
      expect(wrapper.state().pinCodeConfirm).toEqual('');
    });
  });
});

